==> tencentcloud-sdk-java-3.1.310-sources.jar: com/tencentcloudapi/cwp/v20180228/models/AssetKeyVal.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cwp.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class AssetKeyVal extends AbstractModel{

    /**
    * 标签
    */
    @SerializedName("Key")
    @Expose
    private String Key;

    /**
    * 数量
    */
    @SerializedName("Value")
    @Expose
    private Long Value;

    /**
    * 描述信息
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Desc")
    @Expose
    private String Desc;

    /**
     * Get 标签 
     * @return Key 标签
     */
    public String getKey() {
        return this.Key;
    }

    /**
     * Set 标签
     * @param Key 标签
     */
    public void setKey(String Key) {
        this.Key = Key;
    }

    /**
     * Get 数量 
     * @return Value 数量
     */
    public Long getValue() {
        return this.Value;
    }

    /**
     * Set 数量
     * @param Value 数量
     */
    public void setValue(Long Value) {
        this.Value = Value;
    }

    /**
     * Get 描述信息
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Desc 描述信息
注意：此字段可能返回 null，表示取不到有效值。
     */
    public String getDesc() {
        return this.Desc;
    }

    /**
     * Set 描述信息
注意：此字段可能返回 null，表示取不到有效值。
     * @param Desc 描述信息
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setDesc(String Desc) {
        this.Desc = Desc;
    }

    public AssetKeyVal() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public AssetKeyVal(AssetKeyVal source) {
        if (source.Key != null) {
            this.Key = new String(source.Key);
        }
        if (source.Value != null) {
            this.Value = new Long(source.Value);
        }
        if (source.Desc != null) {
            this.Desc = new String(source.Desc);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Key", this.Key);
        this.setParamSimple(map, prefix + "Value", this.Value);
        this.setParamSimple(map, prefix + "Desc", this.Desc);

    }
}

==> tencentcloud-sdk-java-3.1.900-sources.jar: com/tencentcloudapi/cwp/v20180228/models/AssetKeyVal.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cwp.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class AssetKeyVal extends AbstractModel {

    /**
    * 标签
    */
    @SerializedName("Key")
    @Expose
    private String Key;

    /**
    * 数量
    */
    @SerializedName("Value")
    @Expose
    private Long Value;

    /**
    * 描述信息
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Desc")
    @Expose
    private String Desc;

    /**
    * 今日新增数量
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("NewCount")
    @Expose
    private Long NewCount;

    /**
     * Get 标签 
     * @return Key 标签
     */
    public String getKey() {
        return this.Key;
    }

    /**
     * Set 标签
     * @param Key 标签
     */
    public void setKey(String Key) {
        this.Key = Key;
    }

    /**
     * Get 数量 
     * @return Value 数量
     */
    public Long getValue() {
        return this.Value;
    }

    /**
     * Set 数量
     * @param Value 数量
     */
    public void setValue(Long Value) {
        this.Value = Value;
    }

    /**
     * Get 描述信息
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Desc 描述信息
注意：此字段可能返回 null，表示取不到有效值。
     */
    public String getDesc() {
        return this.Desc;
    }

    /**
     * Set 描述信息
注意：此字段可能返回 null，表示取不到有效值。
     * @param Desc 描述信息
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setDesc(String Desc) {
        this.Desc = Desc;
    }

    /**
     * Get 今日新增数量
注意：此字段可能返回 null，表示取不到有效值。 
     * @return NewCount 今日新增数量
注意：此字段可能返回 null，表示取不到有效值。
     */
    public Long getNewCount() {
        return this.NewCount;
    }

    /**
     * Set 今日新增数量
注意：此字段可能返回 null，表示取不到有效值。
     * @param NewCount 今日新增数量
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setNewCount(Long NewCount) {
        this.NewCount = NewCount;
    }

    public AssetKeyVal() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public AssetKeyVal(AssetKeyVal source) {
        if (source.Key != null) {
            this.Key = new String(source.Key);
        }
        if (source.Value != null) {
            this.Value = new Long(source.Value);
        }
        if (source.Desc != null) {
            this.Desc = new String(source.Desc);
        }
        if (source.NewCount != null) {
            this.NewCount = new Long(source.NewCount);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Key", this.Key);
        this.setParamSimple(map, prefix + "Value", this.Value);
        this.setParamSimple(map, prefix + "Desc", this.Desc);
        this.setParamSimple(map, prefix + "NewCount", this.NewCount);

    }
}
